==> jc-1.4.0.tar.gz: java/lang/ref/ReferenceQueue.h <==
// public class java.lang.ref.ReferenceQueue

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 383b9d6c36afac8c java_lang_ref_ReferenceQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ref_ReferenceQueue_H_
#define _JC_java_lang_ref_ReferenceQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ref_Reference$object;

// Typedefs
typedef struct _jc_java_lang_ref_ReferenceQueue$sub_refs	_jc_java_lang_ref_ReferenceQueue$sub_refs;
typedef struct _jc_java_lang_ref_ReferenceQueue$sub_nonrefs	_jc_java_lang_ref_ReferenceQueue$sub_nonrefs;
typedef struct _jc_java_lang_ref_ReferenceQueue$refs	_jc_java_lang_ref_ReferenceQueue$refs;
typedef struct _jc_java_lang_ref_ReferenceQueue$nonrefs	_jc_java_lang_ref_ReferenceQueue$nonrefs;
typedef struct _jc_java_lang_ref_ReferenceQueue$object	_jc_java_lang_ref_ReferenceQueue$object;

typedef const struct _jc_java_lang_ref_ReferenceQueue$vmethods	_jc_java_lang_ref_ReferenceQueue$vmethods;
typedef const struct _jc_java_lang_ref_ReferenceQueue$vtable	_jc_java_lang_ref_ReferenceQueue$vtable;
typedef const struct _jc_java_lang_ref_ReferenceQueue$vtype	_jc_java_lang_ref_ReferenceQueue$vtype;

// Constructors
extern void _jc_java_lang_ref_ReferenceQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);

// Virtual methods
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$dequeue$bf6982870b2faabf(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
extern void _jc_java_lang_ref_ReferenceQueue$method$enqueue$5d8981e22a3e2bf5(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_ref_Reference$object *);
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$poll$d9c3b0e334f418dd(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$remove$cfd62e17ddb58ca8(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$remove$85114945227affe5(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$dequeue$bf6982870b2faabf;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$enqueue$5d8981e22a3e2bf5;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$poll$d9c3b0e334f418dd;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$remove$cfd62e17ddb58ca8;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$remove$85114945227affe5;

// Virtual methods structure
struct _jc_java_lang_ref_ReferenceQueue$vmethods {
	struct _jc_java_lang_ref_Reference$object	*(*dequeue$bf6982870b2faabf)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
	void	(*enqueue$5d8981e22a3e2bf5)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_ref_Reference$object *);
	struct _jc_java_lang_ref_Reference$object	*(*poll$d9c3b0e334f418dd)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
	struct _jc_java_lang_ref_Reference$object	*(*remove$cfd62e17ddb58ca8)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *);
	struct _jc_java_lang_ref_Reference$object	*(*remove$85114945227affe5)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, jlong);
};

// Vtable
struct _jc_java_lang_ref_ReferenceQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_ReferenceQueue$vmethods	java_lang_ref_ReferenceQueue;
};

// Vtype
struct _jc_java_lang_ref_ReferenceQueue$vtype {
	_jc_type			type;
	_jc_java_lang_ref_ReferenceQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_ReferenceQueue$sub_refs {
	struct _jc_java_lang_ref_Reference$object	*first;
};

// Reference instance fields (object)
struct _jc_java_lang_ref_ReferenceQueue$refs {
    _jc_java_lang_ref_ReferenceQueue$sub_refs	java_lang_ref_ReferenceQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_ReferenceQueue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_ReferenceQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_ReferenceQueue$sub_nonrefs	java_lang_ref_ReferenceQueue;
};

// Object instance structure
struct _jc_java_lang_ref_ReferenceQueue$object {
	_jc_java_lang_ref_ReferenceQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_ReferenceQueue$vtype	*vtype;
	_jc_java_lang_ref_ReferenceQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_ReferenceQueue$vtype _jc_java_lang_ref_ReferenceQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_ReferenceQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_ReferenceQueue$class_object;

#endif	/* _JC_java_lang_ref_ReferenceQueue_H_ */

==> jc-1.4.6.tar.gz: java/lang/ref/ReferenceQueue.h <==
// public class java.lang.ref.ReferenceQueue

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 383b9d6c36afac8c java_lang_ref_ReferenceQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ref_ReferenceQueue_H_
#define _JC_java_lang_ref_ReferenceQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ref_Reference$object;

// Typedefs
typedef struct _jc_java_lang_ref_ReferenceQueue$sub_refs	_jc_java_lang_ref_ReferenceQueue$sub_refs;
typedef struct _jc_java_lang_ref_ReferenceQueue$sub_nonrefs	_jc_java_lang_ref_ReferenceQueue$sub_nonrefs;
typedef struct _jc_java_lang_ref_ReferenceQueue$refs	_jc_java_lang_ref_ReferenceQueue$refs;
typedef struct _jc_java_lang_ref_ReferenceQueue$nonrefs	_jc_java_lang_ref_ReferenceQueue$nonrefs;
typedef struct _jc_java_lang_ref_ReferenceQueue$object	_jc_java_lang_ref_ReferenceQueue$object;

typedef const struct _jc_java_lang_ref_ReferenceQueue$vmethods	_jc_java_lang_ref_ReferenceQueue$vmethods;
typedef const struct _jc_java_lang_ref_ReferenceQueue$vtable	_jc_java_lang_ref_ReferenceQueue$vtable;
typedef const struct _jc_java_lang_ref_ReferenceQueue$vtype	_jc_java_lang_ref_ReferenceQueue$vtype;

// Constructors
extern void _jc_java_lang_ref_ReferenceQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$dequeue$bf6982870b2faabf(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ref_ReferenceQueue$method$enqueue$5d8981e22a3e2bf5(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$poll$d9c3b0e334f418dd(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$remove$cfd62e17ddb58ca8(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ref_Reference$object *_jc_java_lang_ref_ReferenceQueue$method$remove$85114945227affe5(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$dequeue$bf6982870b2faabf;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$enqueue$5d8981e22a3e2bf5;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$poll$d9c3b0e334f418dd;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$remove$cfd62e17ddb58ca8;
extern _jc_method _jc_java_lang_ref_ReferenceQueue$method_info$remove$85114945227affe5;

// Virtual methods structure
struct _jc_java_lang_ref_ReferenceQueue$vmethods {
	struct _jc_java_lang_ref_Reference$object	*(*dequeue$bf6982870b2faabf)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
	void	(*enqueue$5d8981e22a3e2bf5)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_ref_Reference$object	*(*poll$d9c3b0e334f418dd)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_ref_Reference$object	*(*remove$cfd62e17ddb58ca8)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_ref_Reference$object	*(*remove$85114945227affe5)(_jc_env *, struct _jc_java_lang_ref_ReferenceQueue$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ref_ReferenceQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_ReferenceQueue$vmethods	java_lang_ref_ReferenceQueue;
};

// Vtype
struct _jc_java_lang_ref_ReferenceQueue$vtype {
	_jc_type			type;
	_jc_java_lang_ref_ReferenceQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_ReferenceQueue$sub_refs {
	struct _jc_java_lang_ref_Reference$object	*first;
};

// Reference instance fields (object)
struct _jc_java_lang_ref_ReferenceQueue$refs {
    _jc_java_lang_ref_ReferenceQueue$sub_refs	java_lang_ref_ReferenceQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_ReferenceQueue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_ReferenceQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_ReferenceQueue$sub_nonrefs	java_lang_ref_ReferenceQueue;
};

// Object instance structure
struct _jc_java_lang_ref_ReferenceQueue$object {
	_jc_java_lang_ref_ReferenceQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_ReferenceQueue$vtype	*vtype;
	_jc_java_lang_ref_ReferenceQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_ReferenceQueue$vtype _jc_java_lang_ref_ReferenceQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_ReferenceQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_ReferenceQueue$class_object;

#endif	/* _JC_java_lang_ref_ReferenceQueue_H_ */
